pub struct ChannelStats {
pub channel_id: String,
pub total_files: usize,
pub total_size: u64,
pub unique_files: usize,
}Expand description
Channel statistics
Fields
channel_id: StringThe channel ID
total_files: usizeTotal number of file references in this channel
total_size: u64Total size of all files in this channel (accounting for sharing)
unique_files: usizeNumber of files that are unique to this channel (files not shared with any other channel)