FileManager - Core file management system
Provides content-addressed storage with deduplication, reference counting, and lazy cleanup. This is the main interface for storing and retrieving files.
Structs
- File
Manager - File manager - main interface for file operations